.. hdfs-native documentation master file, created by
   sphinx-quickstart on Mon Dec 16 14:57:12 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

hdfs-native documentation
=========================

Python bindings for Rust-based `hdfs-native <https://github.com/Kimahriman/hdfs-native>`_ library.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   api
